@@ -15,6 +15,7 @@
 #' @param threads the number of cores to be used in parallel (openmp will be employed)
 #' @param extrema if TRUE then the minimum and maximum values from the k-nearest-neighbors will be removed (can be thought as outlier removal)
 #' @param Levels a numeric vector. In case of classification the unique levels of the response variable are necessary
+#' @param seed_num a numeric value specifying the seed of the random number generator
 #' @return a list of length 2. The first sublist is a list of predictions (the length of the list equals the number of the folds). The second sublist is a list with the indices for each fold.
 #' @author Lampros Mouselimis
 #' @details
@@ -25,16 +26,17 @@
 #' @importFrom utils setTxtProgressBar
 #' @examples
 #'
+#' \dontrun{
 #' data(ionosphere)
 #' 
 #' X = ionosphere[, -c(2, ncol(ionosphere))]
 #' y = as.numeric(ionosphere[, ncol(ionosphere)])
 #'
 #' out = KernelKnnCV(X, y, k = 5, folds = 3, regression = FALSE, Levels = unique(y))
-#' 
+#' }
 
 
-KernelKnnCV = function(data, y, k = 5, folds = 5, h = 1.0, method = 'euclidean', weights_function = NULL, regression = F, transf_categ_cols = F, threads = 1, extrema = F, Levels = NULL) {
+KernelKnnCV = function(data, y, k = 5, folds = 5, h = 1.0, method = 'euclidean', weights_function = NULL, regression = F, transf_categ_cols = F, threads = 1, extrema = F, Levels = NULL, seed_num = 1) {
   
   if (length(y) != nrow(data)) stop('the size of the data and y differ')
   if (!is.logical(regression)) stop('the regression argument should be either TRUE or FALSE')
@@ -49,12 +51,12 @@ KernelKnnCV = function(data, y, k = 5, folds = 5, h = 1.0, method = 'euclidean',
   
   if (regression) {
     
-    set.seed(folds)
+    set.seed(seed_num)
     n_folds = regr_folds(folds, y)}
   
   else {
     
-    set.seed(folds)
+    set.seed(seed_num)
     n_folds = class_folds(folds, as.factor(y))
   }
   
